@@ -366,14 +366,14 @@ def destroy(account_number,role_to_assume_to_target_account,cloudformation_stack
         print(response)
 
         # get ECS instance role from CFN output
-        ecs_instance_role = search_result_dictionary['ECSInstanceRole']
+        ecs_instance_role = search_result_dictionary['ECSInstanceRoleARN']
 
         # delete ECS instance role
         response = iam_assumed_client.delete_role(RoleName=ecs_instance_role)
         print(response)
 
         # get ECS instance profile from CFN output
-        ecs_instance_profile = search_result_dictionary['ECSInstanceProfile']
+        ecs_instance_profile = search_result_dictionary['ECSInstanceProfileName']
 
         # delete instance profile
         response = iam_assumed_client.delete_repository(InstanceProfileName=ecs_instance_profile)
@@ -423,7 +423,7 @@ def fetch_latest_worker_container_code():
 
     return 0
 
-def build_nested_container(path_to_deployment_folder,dev):
+def build_nested_container(path_to_deployment_folder):
     if os.path.exists(os.path.join(os.getcwd(),'docker_folder')):
         shutil.rmtree(os.path.join(os.getcwd(),'docker_folder'))
 
@@ -431,47 +431,28 @@ def build_nested_container(path_to_deployment_folder,dev):
 
     copy_tree(path_to_deployment_folder,os.path.join(os.getcwd(),'docker_folder'))
 
-    # run deployment script if exists
-    if os.path.isfile('deployment_script.sh'):
-        print('"deployment_script.sh" file detected. Setting appropriate file permissions and running now.')
-        rc = subprocess.call("chmod u+rx deployment_script.sh", shell=True)
-        if rc != 0:
-            print('"chmod u+rx deployment_script.sh" call failed!')
+    try:
+        result = subprocess.call('docker rm --force ' + slugify(path_to_deployment_folder) + '_instance ', shell=True)
+    except:
+        pass
 
-        rc = subprocess.call("./deployment_script.sh", shell=True)
-        if rc != 0:
-            print('"./deployment_script.sh" call failed!')
+    try:
+        result = subprocess.call('docker build --no-cache -f Dockerfile.txt -t '+slugify(path_to_deployment_folder)+':latest .',shell=True)
 
-    #if dev flag is set to true build from source otherwise pull from dockerhub
-    if dev == 'True':
+        if result != 0:
+            raise ValueError('Docker build command failed. Could not build initial worker container. Process is being aborted.')
+
+    except:
         try:
-            result = subprocess.call('docker rm --force ' + slugify(path_to_deployment_folder) + '_instance ', shell=True)
-        except:
-            pass
-
-        try:
-            result = subprocess.call('docker build --no-cache -f Dockerfile.txt -t '+slugify(path_to_deployment_folder)+':latest .',shell=True)
+            result = subprocess.call('docker build --no-cache -f Dockerfile -t '+slugify(path_to_deployment_folder)+':latest .',shell=True)
 
             if result != 0:
                 raise ValueError('Docker build command failed. Could not build initial worker container. Process is being aborted.')
 
-        except:
-            try:
-                result = subprocess.call('docker build --no-cache -f Dockerfile -t '+slugify(path_to_deployment_folder)+':latest .',shell=True)
-
-                if result != 0:
-                    raise ValueError('Docker build command failed. Could not build initial worker container. Process is being aborted.')
-
-            except Exception as error:
-                traceback.print_tb(error.__traceback__)
-                print('Could not deploy. Docker was not properly configured or no file named "Dockerfile.txt" or "Dockerfile" was found in the path to deploy from.')
-                raise ValueError(str(error))
-    else:
-        # pull latest Shepard worker container code
-        result = subprocess.call('docker pull sheparddeploybot/shepard-worker-container:latest', shell=True)
-
-        # rename Shepard worker container code to expected name
-        result = subprocess.call('docker image tag sheparddeploybot/shepard-worker-container:latest '+slugify(path_to_deployment_folder)+':latest', shell=True)
+        except Exception as error:
+            traceback.print_tb(error.__traceback__)
+            print('Could not deploy. Docker was not properly configured or no file named "Dockerfile.txt" or "Dockerfile" was found in the path to deploy from.')
+            raise ValueError(str(error))
 
     result = subprocess.call('docker run --name '+slugify(path_to_deployment_folder)+'_instance --privileged=true -v /var/run/docker.sock:/var/run/docker.sock '+slugify(path_to_deployment_folder),shell=True)
 
@@ -556,7 +537,7 @@ def push_to_ecr(account_number,role_to_assume_to_target_account,ecr_repo_to_push
 
     return 0
 
-def deploy(account_number,role_to_assume_to_target_account,cloudformation_stack_name,path_to_deployment_folder,ecr_repo_to_push_to,dont_assume,mfa_token,serial_number,dev):
+def deploy(account_number,role_to_assume_to_target_account,cloudformation_stack_name,path_to_deployment_folder,ecr_repo_to_push_to,dont_assume,mfa_token,serial_number):
     #get default account number from CLI
     region = check_output('aws configure get region', shell=True).strip().decode("utf-8")
 
@@ -648,20 +629,19 @@ def deploy(account_number,role_to_assume_to_target_account,cloudformation_stack_
                     path_to_deployment_folder=path_to_deployment_folder, called_by_deploy_function=True)
 
     #deploy code to ECR
-    if dev == 'True':
-        path_to_docker_folder = os.path.join(path_to_deployment_folder,'code')
-        print('fetching latest worker container code ...')
-        try:
-            fetch_latest_worker_container_code()
-        except Exception as error:
-            traceback.print_tb(error.__traceback__)
-            print('fetching latest worker container code failed')
-            raise ValueError(str(error))
-        print('fetching latest worker container code succeeded')
+    path_to_docker_folder = os.path.join(path_to_deployment_folder,'code')
+    print('fetching latest worker container code ...')
+    try:
+        fetch_latest_worker_container_code()
+    except Exception as error:
+        traceback.print_tb(error.__traceback__)
+        print('fetching latest worker container code failed')
+        raise ValueError(str(error))
+    print('fetching latest worker container code succeeded')
 
     print('building shepard style nested container ...')
     try:
-        build_nested_container(path_to_docker_folder,dev)
+        build_nested_container(path_to_docker_folder)
     except Exception as error:
         traceback.print_tb(error.__traceback__)
         print('building shepard style nested container failed')
